import { taskApp, queue, xhsApp } from '../task.ts';
import { random, omit } from 'lodash-es';
import util from 'node:util';

export const sleep = (ms: number) => {
  return new Promise((resolve) => setTimeout(resolve, ms));
};

taskApp
  .route({
    path: 'task',
    key: 'getUnread',
  })
  .define(async (ctx) => {
    const res = await xhsApp.call({
      path: 'mention',
      key: 'getUnread',
    });
    if (res.code === 200) {
      const data = res.body;
      const unread_count = data.unread_count;
      if (unread_count > 0) {
        queue.add(
          'mention',
          {
            path: 'task',
            key: 'getMention',
            payload: {
              unread_count,
            },
          },
          {
            attempts: 3,
            delay: 0,
            removeOnComplete: true,
            removeOnFail: {
              age: 24 * 3600, // keep up to 24 hours
            },
          },
        );
      }
      ctx.body = {
        job: unread_count,
      };
    }
  })
  .addTo(taskApp);

taskApp
  .route({
    path: 'task',
    key: 'getMention',
  })
  .define(async (ctx) => {
    const { unread_count } = ctx.query;
    if (unread_count > 0) {
      const mentionRes = await xhsApp.call({
        path: 'mention',
        key: 'getMention',
        payload: {
          num: unread_count,
        },
      });
      console.log('mentionRes', mentionRes.body);
      if (mentionRes.code === 200) {
        let data = mentionRes.body || [];
        // data = data.map((item) => omit(item, 'mention'));
        console.log('queryMention', util.inspect(data, { depth: 10 }));
        for (let i = 0; i < data.length; i++) {
          const item = data[i];
          queue.add(
            'mention-ai',
            {
              path: 'task',
              key: 'ai',
              payload: {
                data: item,
              },
            },
            {
              attempts: 3,
              delay: 0,
              removeOnComplete: true,
              removeOnFail: {
                age: 24 * 3600, // keep up to 24 hours
              },
            },
          );
          console.log('add mention task', item);
          await sleep(200);
        }
      }
      const postRead = await xhsApp.call({
        path: 'mention',
        key: 'postRead',
      });
      console.log('postRead', postRead.body);
    }
    await sleep(1000);
    ctx.body = {
      job: unread_count,
    };
  })
  .addTo(taskApp);

taskApp
  .route({
    path: 'task',
    key: 'ai',
  })
  .define(async (ctx) => {
    const data = ctx.query.data;
    const note_id = data.note_id;
    const xsec_token = data.xsec_token;
    const comment_id = data.comment.comment_id;
    const content = data.comment?.content || 'test';
    const postData = {
      note_id,
      content,
      comment_id,
    };
    const res = await xhsApp.call({
      path: 'mention',
      key: 'addComment',
      payload: postData,
    });
    console.log('addComment', postData, 'res', res.body);
  })
  .addTo(taskApp);
